@@ -392,7 +392,8 @@ class GossCodeGenerator(CppCodeGenerator):
         ode = self.ode
 
         # State names
-        state_names = [state.name for state in ode.states]
+        state_names = [state.name for state in ode.full_states]
+
         body = ["", "// State names"]
         body.extend(
             '_state_names[{0}] = "{1}"'.format(i, name)
